@@ -14,7 +14,7 @@ See the docs for these modules for more information::
 
 from future.builtins.iterators import (filter, map, zip)
 from future.builtins.misc import (ascii, oct, hex, chr, int, input, open)
-from future.builtins.backports import (round, range, super)
+from future.builtins.backports import (bytes, round, range, super)
 from future.builtins.str_is_unicode import str  
 from future import utils
 
@@ -29,7 +29,7 @@ if not utils.PY3:
     # Only shadow builtins on Py2; no new names
     __all__ = ['filter', 'map', 'zip', 
                'ascii', 'oct', 'hex', 'chr', 'int', 'input', 'open',
-               'round', 'range', 'super',
+               'bytes', 'round', 'range', 'super',
                'apply', 'cmp', 'coerce', 'execfile', 'file', 'long',
                'raw_input', 'reduce', 'reload', 'unicode', 'xrange',
                'str',
